==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkBoostBreadthFirstSearch.java <==
// java wrapper for vtkBoostBreadthFirstSearch object
//

package vtk;
import vtk.*;

public class vtkBoostBreadthFirstSearch extends vtkGraphAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOriginSelection_2(vtkSelection id0);
  public void SetOriginSelection(vtkSelection id0)
    { SetOriginSelection_2(id0); }

  private native void SetOriginSelectionConnection_3(vtkAlgorithmOutput id0);
  public void SetOriginSelectionConnection(vtkAlgorithmOutput id0)
    { SetOriginSelectionConnection_3(id0); }

  private native void SetOriginVertex_4(int id0);
  public void SetOriginVertex(int id0)
    { SetOriginVertex_4(id0); }

  private native void SetOriginVertexString_5(String id0,String id1);
  public void SetOriginVertexString(String id0,String id1)
    { SetOriginVertexString_5(id0,id1); }

  private native void SetOutputArrayName_6(String id0);
  public void SetOutputArrayName(String id0)
    { SetOutputArrayName_6(id0); }

  private native void SetOriginFromSelection_7(boolean id0);
  public void SetOriginFromSelection(boolean id0)
    { SetOriginFromSelection_7(id0); }

  private native boolean GetOriginFromSelection_8();
  public boolean GetOriginFromSelection()
    { return GetOriginFromSelection_8(); }

  private native void OriginFromSelectionOn_9();
  public void OriginFromSelectionOn()
    { OriginFromSelectionOn_9(); }

  private native void OriginFromSelectionOff_10();
  public void OriginFromSelectionOff()
    { OriginFromSelectionOff_10(); }

  private native boolean GetOutputSelection_11();
  public boolean GetOutputSelection()
    { return GetOutputSelection_11(); }

  private native void SetOutputSelection_12(boolean id0);
  public void SetOutputSelection(boolean id0)
    { SetOutputSelection_12(id0); }

  private native void OutputSelectionOn_13();
  public void OutputSelectionOn()
    { OutputSelectionOn_13(); }

  private native void OutputSelectionOff_14();
  public void OutputSelectionOff()
    { OutputSelectionOff_14(); }

  private native void SetOutputSelectionType_15(String id0);
  public void SetOutputSelectionType(String id0)
    { SetOutputSelectionType_15(id0); }

  public vtkBoostBreadthFirstSearch() { super(); }

  public vtkBoostBreadthFirstSearch(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkBoostBreadthFirstSearch.java <==
// java wrapper for vtkBoostBreadthFirstSearch object
//

package vtk;
import vtk.*;

public class vtkBoostBreadthFirstSearch extends vtkGraphAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOriginSelection_2(vtkSelection id0);
  public void SetOriginSelection(vtkSelection id0)
    { SetOriginSelection_2(id0); }

  private native void SetOriginSelectionConnection_3(vtkAlgorithmOutput id0);
  public void SetOriginSelectionConnection(vtkAlgorithmOutput id0)
    { SetOriginSelectionConnection_3(id0); }

  private native void SetOriginVertex_4(int id0);
  public void SetOriginVertex(int id0)
    { SetOriginVertex_4(id0); }

  private native void SetOriginVertexString_5(String id0,String id1);
  public void SetOriginVertexString(String id0,String id1)
    { SetOriginVertexString_5(id0,id1); }

  private native void SetOutputArrayName_6(String id0);
  public void SetOutputArrayName(String id0)
    { SetOutputArrayName_6(id0); }

  private native void SetOriginFromSelection_7(boolean id0);
  public void SetOriginFromSelection(boolean id0)
    { SetOriginFromSelection_7(id0); }

  private native boolean GetOriginFromSelection_8();
  public boolean GetOriginFromSelection()
    { return GetOriginFromSelection_8(); }

  private native void OriginFromSelectionOn_9();
  public void OriginFromSelectionOn()
    { OriginFromSelectionOn_9(); }

  private native void OriginFromSelectionOff_10();
  public void OriginFromSelectionOff()
    { OriginFromSelectionOff_10(); }

  private native boolean GetOutputSelection_11();
  public boolean GetOutputSelection()
    { return GetOutputSelection_11(); }

  private native void SetOutputSelection_12(boolean id0);
  public void SetOutputSelection(boolean id0)
    { SetOutputSelection_12(id0); }

  private native void OutputSelectionOn_13();
  public void OutputSelectionOn()
    { OutputSelectionOn_13(); }

  private native void OutputSelectionOff_14();
  public void OutputSelectionOff()
    { OutputSelectionOff_14(); }

  private native void SetOutputSelectionType_15(String id0);
  public void SetOutputSelectionType(String id0)
    { SetOutputSelectionType_15(id0); }

  public vtkBoostBreadthFirstSearch() { super(); }

  public vtkBoostBreadthFirstSearch(long id) { super(id); }
  public native long   VTKInit();

}
